// The Vue build version to load with the `import` command
// (runtime-only or standalone) has been set in webpack.base.conf with an alias.
import Vue from 'vue'
import AV from 'leancloud-storage'
import 'normalize.css'
import './assets/reset.css'
import './assets/main.css'
import './assets/iconfont.js'
import * as todoUtil from './todoUtil.js'

Vue.config.productionTip = false

/* eslint-disable no-new */
var APP_ID = 'pYbSeLCYTDqHSr1gUn85Hjno-gzGzoHsz'
var APP_KEY = '1FAdEGMpGcG90I9HuiQRk3JF'

AV.init({
  appId: APP_ID,
  appKey: APP_KEY
})

var vm = new Vue({
  el: '#app',
  data: {
    actionType: 'logIn',
    signUpData: {
      username: '',
      password: ''
    },
    logInData: {
      username: '',
      password: ''
    },
    curUser: null,
    newTodo: {
      title: '',
      content: ''
    },
    todoList: [],
    tip: ''
  },
  template: '',
  components: {},
  watch: {
    actionType: function () {
      this.tip = ''
    }
  },
  methods: {
    addTodo: function () {
      if (this.newTodo.title) {
        let newTodoObj = {
          // createdAt: new Date().toLocaleString(),
          title: this.newTodo.title,
          content: this.newTodo.content || '',
          done: false,
          unfold: false
        }
        this.todoList.push(newTodoObj)
        this.newTodo.title = ''
        this.newTodo.content = ''
        todoUtil.createTodo(newTodoObj, this.curUser)
      } else {
        alert('不能为空')
      }
    },
    modifyTodo: function (todoObj) {
      todoUtil.updateTodo(todoObj)
    },
    removeTodo: function (todoObj) {
      let index = this.todoList.indexOf(todoObj)
      this.todoList.splice(index, 1)
      todoUtil.removeTodo(todoObj)
    },
    signUp: function () {
      let userAV = new AV.User()
      userAV.setUsername(this.signUpData.username)
      userAV.setPassword(this.signUpData.password)
      userAV.signUp().then(function () {
        debugger
        this.curUser = this.getCurrentUser()
        this.todoList = todoUtil.getTodosByUserObj(this.curUser) || []
        this.tip = ''
      }.bind(this), function (err) {
        throw new Error(err)
      }).catch(function (err) {
        this.tip = err.message
        this.signUpData = {
          username: '',
          password: ''
        }
      }.bind(this))
    },
    logIn: function () {
      let user = this.logInData
      console.log('user', user)
      AV.User.logIn(user.username, user.password)
        .then(function () {
          this.curUser = this.getCurrentUser()
          this.todoList = todoUtil.getTodosByUserObj(this.curUser) || []
          this.tip = ''
        }.bind(this), function (err) {
          throw new Error(err)
        }).catch(function (err) {
          console.log(err)
          this.tip = err.message
          this.logInData = {
            username: '',
            password: ''
          }
        }.bind(this))
    },
    logOut: function () {
      AV.User.logOut()
      this.curUser = null
      window.location.reload()
    },
    getCurrentUser: function () {
      let { id, createdAt, attributes: { username } } = AV.User.current()
      return { id, username, createdAt }
    }
  },
  created: function () {
    window.onbeforeunload = function () {
      let dataString = JSON.stringify({
        user: this.curUser,
        newTodo: this.newTodo
      })
      window.localStorage.setItem('data', dataString)
    }.bind(this)
    let oldData = JSON.parse(window.localStorage.getItem('data')) || {}
    this.curUser = oldData.user || null
    this.newTodo = oldData.newTodo || ''
    if (this.curUser) {
      this.todoList = todoUtil.getTodosByUserObj(this.curUser) || []
      console.log(this.todoList)
    }
  }
})
